@@ -6,7 +6,7 @@
                            "SLP", "STATION", "TMP", "VIS", "WND", "air_temp", "atmos_pres",
                            "ceil_hgt", "cl_1", "cl_1_height",
                            "cl_2", "cl_2_height", "cl_3", "cl_3_height", "description",
-                           "dew_point", "latitude",
+                           "dew_point", "latitude", "precip_raw",
                            "longitude", "precip", "visibility", "wd", "weatherCodes", "ws"))
 }
 
